# Image Steganography Library

A simple Python library for encoding and decoding hidden messages in images using steganography.

## Features
- Embed text messages in PNG images.
- Extract hidden messages from steganographed images.


## Installation
GitHub: git clone https://github.com/Jkdxbns/Image-Steganography.git
pip install ImageSteganography